<?php
/*
 * LernfunkPlugin.class.php - vader standard plugin
 *
 * Copyright (C) 2009 - Till Gloeggler <tgloeggl@uos.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */

/**
 * The Lernfunk Plugin
 *
 * @package			virtuos
 * @subpackage	standard
 *
 * @author			tgloeggl
 * @author			aklassen
 * @copyright		(c) Authors
 * @version			$Id$
 */

require_once "LernfunkDB.class.php";
require_once "LernfunkWebservice.class.php";
require_once 'lib/classes/Token.class.php';

class LernfunkPlugin extends AbstractStudIPStandardPlugin {

  function LernfunkPlugin() {

    parent::AbstractStudIPStandardPlugin();

    $this->setPluginiconname("img/plugin.png");

    # navigation
    $top_navigation =& new PluginNavigation();
    $top_navigation->setDisplayname(_("Vorlesungsaufzeichnungen"));
    
		$this->setNavigation($top_navigation);
		
    $this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__) . '/templates/');


    ## AbstractStudIPStandardPlugin specifics

    $this->setChangeindicatoriconname("img/plugin_notice.png");
    $this->setShownInOverview(FALSE);
  }


	function display_action($action) {

		$seminar_id = $this->getId();
		$webservice = new LernfunkWebservice($seminar_id);
		$feed = $webservice->get_feeds();
		global $_include_additional_header;


		foreach ($feed as $key => $value) {
			$_include_additional_header .= '<link rel="alternate" type="application/rss+xml" title="'. $value['feedtype'].'" href="'
				.$value['feed_url'].'">';
		}




		$GLOBALS['CURRENT_PAGE'] = $_SESSION['SessSemName']['header_line'] . ' - ' . $this->getDisplayTitle();

		include 'lib/include/html_head.inc.php';
		include 'lib/include/header.php';

		$pluginparams = $_GET["plugin_subnavi_params"];

		include 'lib/include/links_openobject.inc.php';

		// let the plugin show its view
		StudIPTemplateEngine::startContentTable(true);
		$this->$action($pluginparams);
		StudIPTemplateEngine::endContentTable();

		// close the page
		include 'lib/include/html_end.inc.php';
		page_close();

	}


  function getPluginname() {
    return _("Lernfunk-Plugin");
  }

	function actionShow() {
	    
		// create a token valid for 2 hours
		$user = $this->getUser();
		$token = new Token($user->getUserid(), 7200);

		checkObject(); 

		// get current semester
		$semester = new SemesterData();
		$current_semester = $semester->getCurrentSemesterData();


		$content_info = array(
			'1'  => array( 'icon' => 'virtpresenter.gif', 'storable' => 0),
			'2'  => array(
				'icon' => 'virtpresenter.gif', 
				'storable' => 0,
				'tooltip' => _("Film und Folien synchron in neuem Fenster anzeigen.")
			),       // VirtPresenter-Aufzeichnung mit Folien
			'3'  => array( 'icon' => 'audiomp3.gif', 'storable' => 1),
			'9'  => array( 'icon' => 'camtasia.gif', 'storable' => 0),
			'10' => array( 'icon' => 'flashvideo.gif', 'storable' => 0),
			'11' => array( 'icon' => 'audioipod.gif', 'storable' => 1),
			'12' => array( 'icon' => 'mp4video.gif', 'storable' => 1),
			'13' => array( 'icon' => 'realvideo.gif', 'storable' => 1),
			'14' => array( 'icon' => 'flashvideo.gif', 'storable' => 0),          // Flash-Video
			'15' => array( 'icon' => 'mp4iconschirm.gif', 'storable' => 1),
			'16' => array( 'icon' => 'video.gif', 'storable' => 1),
			'17' => array( 'icon' => 'flashvideo.gif', 'storable' => 1)           // Flash HD
		);

		$seminar_id = $this->getId();
		$webservice = new LernfunkWebservice($seminar_id);
		$feed = $webservice->get_feeds();

		$data = $webservice->list_recordings();
		if (!$data || !is_array($data['recordings'])) {
			$data['recordings'] = array();
		}
		if ($_REQUEST['open']) {
			$open = $_REQUEST['open'];
		} else {
			$open = md5($data['recordings'][0]['cou_id']);
		}

		if ($_REQUEST['set_visibility']) {
			// LernfunkWebservice::set_pub_status($seminar_id, 
		}

		foreach ($data['recordings'] as $content) {
			
			if ($open == md5($content['cou_id'])) {
				foreach ($content['mediaobjects'] as $media) {
					$found_embed[$media['format_id']] = $media['embed'];
					$active_id = ($content['cou_id']);
				}
				if ($found_embed[17]) {
					$embed = $found_embed[17];
				} else {
					$embed = $found_embed[2] ? $found_embed[2] : $found_embed[14];
				}
			}

		}
		$template = $this->template_factory->open('content_list');
		$template->set_layout('layout.php');
		$template->set_attribute('data', $data);
		$template->set_attribute('plugin', $this);
		$template->set_attribute('plugin_path', $this->getPluginURL());
		$template->set_attribute('rss_id', $rss_id);
		$template->set_attribute('rechte', $GLOBALS['perm']->have_studip_perm($GLOBALS['user']->id, $seminar_id));
		$template->set_attribute('content_info', $content_info);
		$template->set_attribute('open', $open);
		$template->set_attribute('active_id',$active_id);
		$template->set_attribute('embed', $embed);
		$template->set_attribute('feed', $feed);
		$template->set_attribute('token', $token->get_token());
		$template->set_attribute('current_semester', $current_semester);
		
		echo $template->render();
	}

	/**
	 * This function checks if the recorded lectures can be displayed with the new virtPresenter-player
	 */
	function useNewPlayer() {
		$fd = fopen('http://vm057.rz.uos.de:8080/virtpresenter/VirtpresenterClient/lectures/seminars.xml', 'r');
		if ($fd) {
			$data = '';

			while ($zw = fgets($fd)) {
				$data .= $zw;
			}

			if (strpos($data, $this->getId())) return true;		// found the seminar_id in the xml-file
		}

		// we use the simple player
		return false;
	}

  function actionShowAdministrationPage() {
    #printf("in %s:%s\n", __CLASS__, __FUNCTION__);
  }


  ## AbstractStudIPStandardPlugin specifics

  function hasChanged($lastlogin) {
    return FALSE;
  }


  # not used
  function getChangeMessages($lastlogin, $ids) {
    return array();
  }
  
}
