<?php
/*
 * LernfunkWebservice.class.php
 *
 * communication with the lernfunk-webservice
 *
 * Copyright (C) 2009 - Till Gloeggler <tgloeggl@uos.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */

require_once('vendor/phpxmlrpc/xmlrpc.inc');

class LernfunkWebservice {
	var $api_key;
	var $lms_id;
	var $webservice_url;
	var $seminar_id;

	/**
	 * create a webservice instance for the seminar with the submitted id
	 *
	 * @param string $seminar_id the seminar to query the webservice for
	 */
	function __construct( $seminar_id ) {
		$webservice = LernfunkDB::getWebserviceInfo();
		$this->api_key = $webservice['api_key'];
		$this->lms_id = $webservice['lms_id'];
		$this->webservice_url = $webservice['webservice_url'];

		$this->seminar_id = $seminar_id;
	}

	/**
	 * query an xml webservice
	 *
	 * @param string the method to call
	 * @param array an array of params to send
	 * @param debug 0, 1, 2 - zero means no debugging
	 *
	 * @return mixed the retrieved data 
	 */
	private function query($method, $params, $debug = 0) {
		$client =& new xmlrpc_client($this->webservice_url);
		$client->return_type = 'xmlrpcvals';
		$client->setDebug($debug);

		$msg =& new xmlrpcmsg($method);
		foreach ($params as $value => $type) {
			$param = new xmlrpcval($value, $type);
			$msg->addparam( $param );
		}

		$res =& $client->send($msg, 0, '');
		if ($res->faultcode()) return false; else return php_xmlrpc_decode($res->value());
	}


	/* * * * * * * * * * * * * * * * * * * * * * * * * * *
	 * *   W E B S E R V I C E   E N D - P O I N T S   * *
	 * * * * * * * * * * * * * * * * * * * * * * * * * * */

	public function list_recordings() {
		$params[$this->api_key] = 'string';
		$params[$this->seminar_id] = 'string';
		$params[$this->lms_id] = 'string';

		return $this->query( 'list_recordings', $params );
	}
	
	public function get_feeds() {
	  $params[$this->api_key] = 'string';
		$params[$this->seminar_id] = 'string';
		$params[$this->lms_id] = 'string';
		
		return $this->query( 'get_feeds', $params );
	   
	}

	public function set_pub_status($seminar_id, $cou_id, $type, $visible, $webservice) {
		/*
		// set parameters for xmlrpc-request
		$request = xmlrpc_encode_request("list_recordings", 
			array($webservice['api_key'], $seminar_id, $webservice['lms_id'], $cou_id, $type));

		// create stream context
		$context = stream_context_create(array('http' => array(
			'method' => "POST",
			'header' => "Content-Type: text/xml",
			'content' => $request
		)));

		file_get_contents($webservice['webservice_url'], false, $context);
		*/
	}
}
